@@ -7,7 +7,7 @@ use base qw(Exporter);
 
 our @EXPORT = qw(check_cvs cvs_tag make_cvs_tag);
 
-our $VERSION = '0.10_02';
+our $VERSION = '0.10_03';
 
 =head1 NAME
 
@@ -32,7 +32,7 @@ This module depends on the external git binary (so far).
 
 =over 4
 
-=item C<check_cvs()>
+=item check_cvs()
 
 Check the state of the Git repository.
 
@@ -60,7 +60,7 @@ sub check_cvs
 	return 1;
 	}
 
-=item C<cvs_tag(TAG)>
+=item cvs_tag(TAG)
 
 Tag the release in local Git.
 
@@ -70,6 +70,8 @@ sub cvs_tag
 	{
 	my( $self, $tag ) = @_;
 	
+	$tag ||= $self->make_cvs_tag;
+	
 	$self->_print( "Tagging release with $tag\n" );
 
 	$self->run( 'git tag $tag' );
